@@ -1,3 +1,19 @@
+#!/usr/bin/python
+#
+#  Copyright 2002-2022 Barcelona Supercomputing Center (www.bsc.es)
+#
+#  Licensed under the Apache License, Version 2.0 (the "License");
+#  you may not use this file except in compliance with the License.
+#  You may obtain a copy of the License at
+#
+#      http://www.apache.org/licenses/LICENSE-2.0
+#
+#  Unless required by applicable law or agreed to in writing, software
+#  distributed under the License is distributed on an "AS IS" BASIS,
+#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+#  See the License for the specific language governing permissions and
+#  limitations under the License.
+#
 """
 This file contains the actions supported by pycompss-cli.
 They are invoked from cli/pycompss.py and uses core/cmd.py.
@@ -145,7 +161,8 @@ class DockerActions(Actions):
                 f"--ip={self.env_conf['master_ip']} " + \
                 "--allow-root " + \
                 "--NotebookApp.token="
-        self.docker_cmd.docker_exec_in_daemon(jupyter_cmd)
+        for out_line in self.docker_cmd.docker_exec_in_daemon(jupyter_cmd, return_stream=True):
+            print(out_line.decode().strip().replace(self.env_conf['master_ip'], 'localhost'))
 
         if self.docker_cmd.exists():
             self.docker_cmd.docker_exec_in_daemon('pkill jupyter')
@@ -203,4 +220,4 @@ class DockerActions(Actions):
 
     def job(self):
         print("ERROR: Wrong Environment! Try using a `remote` environment")
-        exit(1)
\ No newline at end of file
+        exit(1)
