@@ -1,3 +1,19 @@
+#!/usr/bin/python
+#
+#  Copyright 2002-2022 Barcelona Supercomputing Center (www.bsc.es)
+#
+#  Licensed under the Apache License, Version 2.0 (the "License");
+#  you may not use this file except in compliance with the License.
+#  You may obtain a copy of the License at
+#
+#      http://www.apache.org/licenses/LICENSE-2.0
+#
+#  Unless required by applicable law or agreed to in writing, software
+#  distributed under the License is distributed on an "AS IS" BASIS,
+#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+#  See the License for the specific language governing permissions and
+#  limitations under the License.
+#
 import json
 import os
 import sys
@@ -173,7 +189,7 @@ class DockerCmd(object):
         self._stop_by_name(worker_name)
 
 
-    def docker_exec_in_daemon(self, cmd: str, return_output=False) -> None:
+    def docker_exec_in_daemon(self, cmd: str, return_output=False, return_stream=False) -> None:
         """ Execute the given command in the main COMPSs image in Docker.
 
         :param cmd: Command to execute.
@@ -185,8 +201,11 @@ class DockerCmd(object):
 
         master = self._get_master()
         _, output = master.exec_run(cmd, workdir=default_workdir, stream=True)
+        
         if return_output:
             return list(output)[-1].decode().strip()
+        if return_stream:
+            return output
         try:
             for line in output:
                 print(line.strip().decode())
@@ -580,4 +599,4 @@ class DockerCmd(object):
         """
         containers = self.client.containers.list(filters={"name": name}, all=True)
         for c in containers:
-            c.remove(force=True)
\ No newline at end of file
+            c.remove(force=True)
